==> objectfile-1.0.0-rc9-sources.jar: com/oracle/objectfile/macho/MachOCpuType.java <==
/*
 * Copyright (c) 2013, 2017, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.oracle.objectfile.macho;

/**
 * Mach-O CPU type.
 */
public enum MachOCpuType {
    X86_64,
    POWERPC64;

    public static MachOCpuType from(int c) {
        switch (c) {
            case 0x01000007:
                return X86_64;
            case 0x01000012:
                return POWERPC64;
        }
        throw new IllegalStateException("unknown CPU type");
    }

    public int toInt() {
        switch (this) {
            case X86_64:
                return 0x01000007;
            case POWERPC64:
                return 0x01000012;
        }
        throw new IllegalStateException("should not reach here");
    }
}

==> objectfile-19.2.0.1-sources.jar: com/oracle/objectfile/macho/MachOCpuType.java <==
/*
 * Copyright (c) 2013, 2017, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.oracle.objectfile.macho;

/**
 * Mach-O CPU type.
 */
public enum MachOCpuType {
    X86_64,
    POWERPC64,
    ARM,
    ARM64;

    public static MachOCpuType from(int c) {
        switch (c) {
            case 0x01000007:
                return X86_64;
            case 0x01000012:
                return POWERPC64;
            case 0x0000000C:
                return ARM;
            case 0x0100000C:
                return ARM64;
        }
        throw new IllegalStateException("unknown CPU type");
    }

    public int toInt() {
        switch (this) {
            case X86_64:
                return 0x01000007;
            case POWERPC64:
                return 0x01000012;
            case ARM:
                return 0x0000000C;
            case ARM64:
                return 0x0100000C;
        }
        throw new IllegalStateException("should not reach here");
    }
}
